Author: mtredinnick
Date: 2008-10-24 02:14:30 -0500 (Fri, 24 Oct 2008)
New Revision: 9255

Modified:
   django/trunk/django/forms/fields.py
   django/trunk/docs/ref/forms/validation.txt
Log:
Fixed #9384 -- Fixed a couple of typos. Thanks, Thomas G?\195?\188ttler and 
romke.


Modified: django/trunk/django/forms/fields.py
===================================================================
--- django/trunk/django/forms/fields.py 2008-10-24 06:24:04 UTC (rev 9254)
+++ django/trunk/django/forms/fields.py 2008-10-24 07:14:30 UTC (rev 9255)
@@ -667,7 +667,7 @@
         self.coerce = kwargs.pop('coerce', lambda val: val)
         self.empty_value = kwargs.pop('empty_value', '')
         super(TypedChoiceField, self).__init__(*args, **kwargs)
-        
+
     def clean(self, value):
         """
         Validate that the value is in self.choices and can be coerced to the
@@ -676,12 +676,12 @@
         value = super(TypedChoiceField, self).clean(value)
         if value == self.empty_value or value in EMPTY_VALUES:
             return self.empty_value
-        
+
         # Hack alert: This field is purpose-made to use with Field.to_python as
         # a coercion function so that ModelForms with choices work. However,
-        # Django's Field.to_python raises 
django.core.exceptions.ValidationError,
         # which is a *different* exception than
         # django.forms.utils.ValidationError. So unfortunatly we need to catch
         # both.
         try:
             value = self.coerce(value)

Modified: django/trunk/docs/ref/forms/validation.txt
===================================================================
--- django/trunk/docs/ref/forms/validation.txt  2008-10-24 06:24:04 UTC (rev 
9254)
+++ django/trunk/docs/ref/forms/validation.txt  2008-10-24 07:14:30 UTC (rev 
9255)
@@ -100,10 +100,10 @@
 
 When you really do need to attach the error to a particular field, you should
 store (or amend) a key in the `Form._errors` attribute. This attribute is an
-instance of a ``django.form.utils.ErrorDict`` class. Essentially, though, it's
+instance of a ``django.forms.util.ErrorDict`` class. Essentially, though, it's
 just a dictionary. There is a key in the dictionary for each field in the form
 that has an error. Each value in the dictionary is a
-``django.form.utils.ErrorList`` instance, which is a list that knows how to
+``django.forms.util.ErrorList`` instance, which is a list that knows how to
 display itself in different ways. So you can treat `_errors` as a dictionary
 mapping field names to lists.
 


--~--~---------~--~----~------------~-------~--~----~
You received this message because you are subscribed to the Google Groups 
"Django updates" group.
To post to this group, send email to django-updates@googlegroups.com
To unsubscribe from this group, send email to [EMAIL PROTECTED]
For more options, visit this group at 
http://groups.google.com/group/django-updates?hl=en
-~----------~----~----~----~------~----~------~--~---
@@ -676,12 +676,12 @@
django.core.exceptions.ValidationError,
-        # which is a *different* exception than
-        # django.forms.utils.ValidationError. So unfortunatly we need to catch
+        # Django's Field.to_python raises
+        # django.core.exceptions.ValidationError, which is a *different*
+        # exception than django.forms.util.ValidationError. So we need to catch
         # both.
         try:

Reply via email to